test/hotspot/jtreg/serviceability/sa/ClhsdbCDSCore.java
changeset 52960 a6182c464b31
parent 51946 7bd8d6b011c9
child 53635 247e5ca412f5
--- a/test/hotspot/jtreg/serviceability/sa/ClhsdbCDSCore.java	Tue Dec 11 19:55:27 2018 -0800
+++ b/test/hotspot/jtreg/serviceability/sa/ClhsdbCDSCore.java	Wed Dec 12 10:13:11 2018 +0530
@@ -23,8 +23,8 @@
 
 /**
  * @test
  * @bug 8174994
  * @summary Test the clhsdb commands 'printmdo', 'printall' on a CDS enabled corefile.
  * @requires vm.cds
  * @requires vm.hasSA
  * @requires os.family != "windows"
@@ -156,7 +156,7 @@
                 throw new SkippedException("The CDS archive is not mapped");
             }
 
-            cmds = List.of("printmdo -a", "printall");
+            cmds = List.of("printmdo -a", "printall", "jstack -v");
 
             Map<String, List<String>> expStrMap = new HashMap<>();
             Map<String, List<String>> unExpStrMap = new HashMap<>();
@@ -182,6 +182,11 @@
                 "illegal code",
                 "Failure occurred at bci",
                 "No suitable match for type of address"));
+            expStrMap.put("jstack -v", List.of(
+                "Common-Cleaner",
+                "Method*"));
+            unExpStrMap.put("jstack -v", List.of(
+                "sun.jvm.hotspot.debugger.UnmappedAddressException"));
             test.runOnCore(TEST_CDS_CORE_FILE_NAME, cmds, expStrMap, unExpStrMap);
         } catch (SkippedException e) {
             throw e;
@@ -23,8 +23,8 @@
 /**
  * @test
- * @bug 8174994
- * @summary Test the clhsdb commands 'printmdo', 'printall' on a CDS enabled corefile.
+ * @bug 8174994 8200613
+ * @summary Test the clhsdb commands 'printmdo', 'printall', 'jstack' on a CDS enabled corefile.
  * @requires vm.cds
  * @requires vm.hasSA